unit BeeGui_ConfigFrm;

{ Contains:

  beeGUI Config form.

  (C) 2005 Andrew Filinsky, Melchiorre Caruso

  Modifyed:

  v1.0.1 build 9156 - 2005/07/16 Melchiorre Caruso
  v1.0.1 build 9158 - 2005/07/24 Melchiorre Caruso

}

{$R-,Q-,S-}

interface

uses
  Menus,
  Buttons,
  Classes,
  Dialogs,
  SysUtils,
  Graphics,
  Controls,
  StdCtrls,
  ComCtrls,
  ExtCtrls,
  FileCtrl,

  BeeGui_Forms,
  BeeGui_ListView, ImgList;

const
  UPBTN2EXIT_IDENT   = 'ConfigFrm_General_Options_UpAsExit.Checked';
  UPBTN2EXIT_CLASS   = 'TCheckBox';

  HIDEMAINFRM_IDENT  = 'ConfigFrm_General_Options_HideMainFrm.Checked';
  HIDEMAINFRM_CLASS  = 'TCheckBox';

  PPriority_CLASS    = 'TComboBox';
  PPriority_IDENT    = 'ConfigFrm_Priority.ItemIndex';

type
  TConfigFrm = class (TBGConfigForm)

    ConfigFrm_Tree: TTreeView;
    AddFrm_OptionsGB: TGroupBox;
    AddFrm_rOption: TCheckBox;
    AddFrm_sOption: TCheckBox;
    AddFrm_tOption: TCheckBox;
    AddFrm_pOption: TCheckBox;
    AddFrm_MethodGB: TGroupBox;
    AddFrm_Method: TComboBox;
    AddFrm_DictionaryGB: TGroupBox;
    AddFrm_Dictionary: TComboBox;

    // Extract Group Box
    ExtractFrm_ExtrOverWrite_: TGroupBox;
    ExtractFrm_ExtrOverWrite: TComboBox;
    ExtractFrm_ExtrOptions: TGroupBox;
    ExtractFrm_ExtrDirName: TCheckBox;

    // Skin Group Box
    ConfigFrm_Skin_SelectGB: TGroupBox;
    ConfigFrm_Skin_SelectIMAGE: TImage;

    // Notebook
    ConfigFrm_Notebook: TNotebook;
    ConfigFrm_Notebook_Add: TGroupBox;
    ConfigFrm_Notebook_Skin: TGroupBox;
    ConfigFrm_Notebook_General: TGroupBox;
    ConfigFrm_Notebook_Extract: TGroupBox;

    // Buttons
    BtnOk: TBitBtn;
    BtnCancel: TBitBtn;
    AddFrm_cOption: TCheckBox;
    ExtractFrm_cOption: TCheckBox;
    ConfigFrm_General_OptionsGB: TGroupBox;
    ConfigFrm_General_Options_UpAsExit: TCheckBox;
    ConfigFrm_PriorityGB: TGroupBox;
    ConfigFrm_Priority: TComboBox;
    ConfigFrm_Skin_SelectCB: TBGComboBox;
    ConfigFrm_Btns_ListView: TListView;
    ConfigFrm_Btns_Images: TImageList;
    ConfigFrm_Btns_SelectLabel: TLabel;
    ConfigFrm_General_Options_HideMainFrm: TCheckBox;

    procedure FormCreate (Sender: TObject);
    procedure ConfigFrm_Skin_SelectCBClick (Sender: TObject);
    procedure ConfigFrm_Skin_SelectCBEnter (Sender: TObject);
    procedure ConfigFrm_Btns_ListViewClick (Sender: TObject);
    procedure ConfigFrm_TreeChange (Sender: TObject; Node: TTreeNode);
   

  private
    { Private declarations }
    Popup:    TPopupMenu;
    procedure Load_SelectIMAGE (fname: ansistring);
  public
    { Public declarations }
    procedure Get_Btns_PopupMenu;
    procedure Set_Btns_PopupMenu  (aPopup: TPopupMenu);
  end;

var
  ConfigFrm: TConfigFrm;

  procedure myLoadBtnsSkin (var BTNs: array of TControl);

implementation

uses
  BeeGui_WinOS,
  BeeGui_Common;

{$R *.DFM}

procedure TConfigFrm.FormCreate (Sender: TObject);
var
  fname: ansistring;
  T: TSearchRec;
begin
  ConfigFrm_Tree.Items [0].Selected := True;

  fname := ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER) + ConfigFrm_Skin_SelectCB.Items [ConfigFrm_Skin_SelectCB.ItemIndex];

  if not FileExists (fname) then
    if FindFirst (ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER_MASK), faAnyFile - faDirectory, T) = 0 then
      fname  := ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER) + T.Name;

  if FileExists (fname) then Load_SelectIMAGE (fname);
end;

procedure TConfigFrm.ConfigFrm_TreeChange (Sender: TObject; Node: TTreeNode);
begin
  ConfigFrm_Notebook.PageIndex := ConfigFrm_Tree.Selected.AbsoluteIndex;
end;

procedure TConfigFrm.ConfigFrm_Skin_SelectCBClick (Sender: TObject);
var
  fname: ansistring;
begin
  if ConfigFrm_Skin_SelectCB.Items [ConfigFrm_Skin_SelectCB.ItemIndex] = '' then ConfigFrm_Skin_SelectCB.ItemIndex := 0;

  fname := ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER) + ConfigFrm_Skin_SelectCB.Items [ConfigFrm_Skin_SelectCB.ItemIndex];
  if FileExists (fname) then Load_SelectIMAGE (fname);
end;

procedure TConfigFrm.ConfigFrm_Skin_SelectCBEnter (Sender: TObject);
var
  I: integer;
  T: TSearchRec;
begin
  I := 0;
  if FindFirst (ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER_MASK), faAnyFile - faDirectory, T) = 0 then
    repeat
      ConfigFrm_Skin_SelectCB.Items [I] := T.Name;
      Inc (I);
    until (not (FindNext (T) = 0)) or (I = 10);
  FindClose (T);

  while I < ConfigFrm_Skin_SelectCB.Items.Count do
  begin
    ConfigFrm_Skin_SelectCB.Items [I] := '';
    Inc (I);
  end;
end;

procedure TConfigFrm.Load_SelectIMAGE;
var
  b1, b2 : TBitmap;
  x, y, i: integer;
begin
  b1 := TBitmap.Create;
  b2 := TBitmap.Create;
  try
    b1.LoadFromFile (fname);
    b2.Height := b1.Height;
    b2.Width  := b2.Height * 8;

    for i := 0 to 7 do
      for y := 0 to b1.Height -1 do
        for x := 0 to b1.Height -1 do
          b2.Canvas.Pixels [i * b1.Height + x, y] := b1.Canvas.Pixels [i * 2 * b1.Height + x, y];

    ConfigFrm_Skin_SelectIMAGE.Width  := b2.Width;
    ConfigFrm_Skin_SelectIMAGE.Height := b2.Height;
    ConfigFrm_Skin_SelectIMAGE.Canvas.Draw (0, 0, b2);
  finally
    b1.Destroy;
    b2.Destroy;
  end;
end;

procedure TConfigFrm.Set_Btns_PopupMenu;
var
  I: integer;
  lvItem: TListItem;
begin
  Popup := aPopup;
  for I := 0 to Popup.Items.Count - 1 do
  begin
    lvItem := ConfigFrm_Btns_ListView.Items.Add;
    lvItem.Caption := Popup.Items [I].Caption;
    if Popup.Items [I].Checked then
      lvItem.ImageIndex := 0
    else
      lvItem.ImageIndex := 1;
  end;
end;

procedure TConfigFrm.Get_Btns_PopupMenu;
var
  I: integer;
begin
  if Assigned (Popup) then
    for I := 0 to Popup.Items.Count - 1 do
      Popup.Items [I].Checked := (ConfigFrm_Btns_ListView.Items [I].ImageIndex = 0);
end;

procedure TConfigFrm.ConfigFrm_Btns_ListViewClick (Sender: TObject);
begin
  if ConfigFrm_Btns_ListView.SelCount = 0 then Exit;

  if ConfigFrm_Btns_ListView.Selected.ImageIndex = 1 then
    ConfigFrm_Btns_ListView.Selected.ImageIndex := 0
  else
    ConfigFrm_Btns_ListView.Selected.ImageIndex := 1;
end;


// ------------------------------------------------------ //
//                                                        //
// functions and procedures                               //
//                                                        //
// ------------------------------------------------------ //

procedure myLoadBtnsSkin;
var
  fname: ansistring;
  findex: integer;
  I, J: integer;
  Image: TBitmap;
  ImageList: TImageList;
  T: TSearchRec;
begin
  findex := GetIntegerValue (TBGComboBox.ClassName, 'ConfigFrm_Skin_SelectCB.ItemIndex', True);
  fname  := ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER);
  fname  := fname + GetStrValue (TBGComboBox.ClassName, 'ConfigFrm_Skin_SelectCB.Items[' + IntToStr (findex) + ']', True);

  if not FileExists (fname) then
  begin
    if FindFirst (ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER_MASK), faAnyFile - faDirectory, T) = 0 then
      fname  := ExtractFilePath (ParamStr (0)) + DoDelimiter (SKIN_FOLDER) + T.Name;
  end;

  if FileExists (fname) then
  begin
    Image := TBitmap.Create;
    ImageList := TImageList.Create (nil);
    try
      Image.LoadFromFile (fname);
      ImageList.Height := Image.Height;
      ImageList.Width := Image.Height * 2;
      ImageList.BkColor:= clFuchsia;
      ImageList.Add (Image, nil);

      I := 0;
      for J := 0 to High (Btns) do
      if (Btns [J].ClassType = TSpeedButton)then
      begin
        TSpeedButton (Btns [J]).Glyph.FreeImage;
        TSpeedButton (Btns [J]).Glyph.Width  := 0;
        TSpeedButton (Btns [J]).Glyph.Height := 0;
        ImageList.GetBitmap (I, TSpeedButton (Btns [J]).Glyph);
        Inc (I);
      end;
    finally
      ImageList.Free;
      Image.Free;
    end;
  end;
end;









end.
