unit BeeGui_InfoFrm;

{ Contains:

  beeGUI Information form.

  (C) 2005 Andrew Filinsky, Melchiorre Caruso

  Modifyed:

  v1.0.1 build 9155 - 2005/07/15 Melchiorre Caruso
  v1.0.1 build 9158 - 2005/07/24 Melchiorre Caruso

}

{$R-,Q-,S-}

interface

uses
  Dialogs,
  Buttons,
  Classes,
  StdCtrls,
  ExtCtrls,
  Graphics,
  Controls,
  ComCtrls,
  SysUtils,

  BeeGui_Forms, // BeeGuiCustomFrm
  BeeGui_Common,
  BeeGui_ListView;

type
  TInfoFrm = class (TBGCustomForm)
  
    InfoFrm_Pages: TPageControl;
    InfoFrm_PageGeneral: TTabSheet;

    InfoFrm_ArchiveName_: TLabel;
    InfoFrm_Version_: TLabel;
    InfoFrm_Files_: TLabel;
    InfoFrm_Packed_: TLabel;
    InfoFrm_Packed: TLabel;
    InfoFrm_Ratio_: TLabel;
    InfoFrm_R: TLabel;
    InfoFrm_Ratio: TLabel;
    InfoFrm_Size_: TLabel;
    InfoFrm_Size: TLabel;
    InfoFrm_Files: TLabel;
    InfoFrm_Modified_: TLabel;
    InfoFrm_Modified: TLabel;
    InfoFrm_UpEmpty: TImage;
    InfoFrm_DownFull: TImage;
    InfoFrm_Level: TImage;
    InfoFrm_Empty: TImage;
    InfoFrm_Full: TImage;
    InfoFrm_Bevel_1: TBevel;
    InfoFrm_FilesCrypted_: TLabel;
    InfoFrm_FilesCrypted: TLabel;
    InfoFrm_Bevel2: TBevel;
    InfoFrm_Title: TLabel;
    InfoFrm_Version: TLabel;
    InfoFrm_ArchiveName: TLabel;
    InfoFrm_DownEmpty: TImage;
    InfoFrm_UpFull: TImage;
    InfoFrm_ArcSize_: TLabel;
    InfoFrm_ArcSize: TLabel;
    BtnOk: TBitBtn;

    procedure FormResize (Sender: TObject);
  private
    { Private declarations }
    Ratio : integer;
    
  public
    { Public declarations }
    function  UpdateInfo (Info: TBGInfo): boolean;
    procedure UpdateProgressBar;
  end;

var
  InfoFrm: TInfoFrm;

implementation

{$R *.DFM}

procedure TInfoFrm.UpdateProgressBar;
var
  Percentage: integer;
begin
  Percentage := Ratio;

  InfoFrm_UpEmpty.Visible := False;
  InfoFrm_UpFull.Visible := False;
  InfoFrm_Empty.Visible := False;
  InfoFrm_Level.Visible := False;
  InfoFrm_Full.Visible := False;
  InfoFrm_DownFull.Visible := False;
  InfoFrm_DownEmpty.Visible := False;

  InfoFrm_UpFull.Left := InfoFrm_UpEmpty.Left;
  InfoFrm_Empty.Left := InfoFrm_UpEmpty.Left;
  InfoFrm_Level.Left := InfoFrm_UpEmpty.Left;
  InfoFrm_Full.Left := InfoFrm_UpEmpty.Left;
  InfoFrm_DownFull.Left := InfoFrm_UpEmpty.Left;
  InfoFrm_DownEmpty.Left := InfoFrm_UpEmpty.Left;

  InfoFrm_UpFull.Top := InfoFrm_UpEmpty.Top;
  InfoFrm_DownFull.Top := InfoFrm_DownEmpty.Top + InfoFrm_DownEmpty.Height - InfoFrm_DownFull.Height;

  InfoFrm_R.Caption := IntToStr(Percentage) + '%';
  if Percentage > 100 then Percentage := 100;
  case Percentage of
  0..6 : begin
           InfoFrm_Empty.Top := InfoFrm_UpEmpty.Top + InfoFrm_UpEmpty.Height;
           InfoFrm_Empty.Height := InfoFrm_DownEmpty.Top - InfoFrm_Empty.Top;

           InfoFrm_UpEmpty.Visible := True;
           InfoFrm_Empty.Visible := True;
           InfoFrm_DownEmpty.Visible := True;

           InfoFrm_R.Top := InfoFrm_DownEmpty.Top - 3;
         end;
  7..99: begin
           case Percentage of
           97..99: Percentage := 96;
           end;
           InfoFrm_Full.Height := 1 + (InfoFrm_DownFull.Top - InfoFrm_UpEmpty.Top - InfoFrm_UpEmpty.Height - InfoFrm_Level.Height-1) * (Percentage - 7) div (96 - 7);

           InfoFrm_Full.Top := InfoFrm_DownFull.Top - InfoFrm_Full.Height;
           InfoFrm_Level.Top := InfoFrm_Full.Top - InfoFrm_Level.Height;
           InfoFrm_Empty.Top := InfoFrm_UpEmpty.Top + InfoFrm_UpEmpty.Height;
           InfoFrm_Empty.Height := InfoFrm_Level.Top - InfoFrm_Empty.Top;

           InfoFrm_UpEmpty.Visible := True;
           InfoFrm_Empty.Visible := True;
           InfoFrm_Level.Visible := True;
           InfoFrm_Full.Visible := True;
           InfoFrm_DownFull.Visible := True;

           InfoFrm_R.Top := InfoFrm_Level.Top;
         end;
    100: begin
           InfoFrm_Full.Top := InfoFrm_UpFull.Top + InfoFrm_UpFull.Height;
           InfoFrm_Full.Height := InfoFrm_DownFull.Top - InfoFrm_Full.Top;

           InfoFrm_UpFull.Visible := True;
           InfoFrm_Full.Visible := True;
           InfoFrm_DownFull.Visible := True;

           InfoFrm_R.Top := InfoFrm_UpFull.Top;
         end;
  end;
end;

function TInfoFrm.UpdateInfo;
begin
  Result := True;
  if Assigned (Info) then
  try
    if Info.FilesSize = 0 then
      Ratio  := 0
    else
      Ratio := (100 * Info.FilesPacked) div Info.FilesSize;

    InfoFrm_ArchiveName.Caption  := ExtractFileName (Info.ArcName);
    InfoFrm_Version.Caption      := Info.Version;
    InfoFrm_Files.Caption        := IntToStr (Info.FilesCount);
    InfoFrm_Size.Caption         := SizeToStr (Info.FilesSize);
    InfoFrm_Packed.Caption       := SizeToStr (Info.FilesPacked);
    InfoFrm_Ratio.Caption        := IntToStr (Ratio) + '%';
    InfoFrm_FilesCrypted.Caption := IntToStr (Info.FilesCrypted);
    InfoFrm_ArcSize.Caption      := SizeToStr (Info.ArcSize);
    InfoFrm_Modified.Caption     := DateTimeToStr (FileDateToDateTime (Info.Modified));
  except
    Result := False;
  end;
end;

procedure TInfoFrm.FormResize (Sender: TObject);
begin
  UpdateProgressBar;
end;

end.
