unit BeeGui_Common;

{ Contains:

  Various helper routines.

  (C) 2005 Andrew Filinsky, Melchiorre Caruso

  Modifyed:

  v1.0.1 build 9140 - 2005/07/08 Melchiorre Caruso
  v1.0.1 build 9154 - 2005/07/22 Melchiorre Caruso
  v1.0.1 build 9158 - 2005/07/24 Melchiorre Caruso

}

{$R-,Q-,S-}

interface

uses
  Math,
  Classes,
  SysUtils;

const
  KB_SIZE           = 1024;
  MB_SIZE           = KB_SIZE * 1024;
  GB_SIZE           = MB_SIZE * 1024;


  BUDDEL            = '/';
  DELIMITER         = '\';
  DBDELIMITER       = '\\';

  DOC_FOLDER        = 'docs\';
  HLP_FILENAME      = DOC_FOLDER + 'help.htm';
  LIC_FILENAME      = DOC_FOLDER + 'license.htm';

  SKIN_FOLDER       = 'skins\';
  SKIN_FOLDER_MASK  = SKIN_FOLDER + '*.bmp';

  CHECKOUTDIR       = 'checkout';
  TEMPDIR           = '~tempdir';

function  IncludeDelimiter (const S: string): string;
function  ExcludeDelimiter (const S: string): string;
function  DoDelimiter (const S: string): string;

function  SizeToStr (Size: integer): string;
function  RatioToStr (Ratio: integer): string;
function  AttrToStr (Attr: integer): string;

function  PosText (const SubStr: string; const S: string): Integer;

function  ReturnCheckOutDir: string;
function  ReturnTempDir: string;
procedure DeleteCheckOutDir;
procedure DeleteTempDir;

function  SetPriority (Priority: integer): TThreadPriority; // Priority is 0..3

implementation

function IncludeChar (const S: string; C: Char): string;
begin
  Result := S;
  if (not (Length (Result) = 0)) and (not (Result [Length (Result)] = C)) then
    Result := Result + C;
end;

function IncludeDelimiter;
begin
  Result := IncludeChar (S, Delimiter);
  while pos(DbDelimiter, Result) > 0 do delete (Result, pos(DbDelimiter, Result), 1);
end;

function ExcludeDelimiter;
begin
  Result := S;
  while (not (                    Length (Result)  =   0)) and
        (not (Pos (':', Result) = Length (Result)     -1)) and
        (               Result   [Length (Result)] = Delimiter)  do
    SetLength (Result, Length (Result) -1);
end;

function DoDelimiter;
var
  I: integer;
begin
  Result := S;
  I := pos (BudDel, Result);
  while not (I = 0) do
  begin
    Result [I] := Delimiter;
    I := pos (BudDel, Result);
  end;
end;

function SizeToStr;
begin
  if Size < KB_SIZE then
    Result := Format ('%u B', [Size])
  else
    if Size < MB_SIZE then
      Result := Format ('%f KB', [Size / KB_SIZE])
    else
      if Size < GB_Size then
        Result := Format ('%f MB', [Size / MB_SIZE])
      else
        Result := Format ('%f GB', [Size / MB_SIZE]);
end;

function RatioToStr;
begin
  Result := Format ('%u%%', [Ratio]);
end;

function AttrToStr;
begin
  Result := '.DRHSA';
  if Attr and faDirectory = 0 then Result [2] := '.';
  if Attr and faReadOnly  = 0 then Result [3] := '.';
  if Attr and faHidden    = 0 then Result [4] := '.';
  if Attr and faSysFile   = 0 then Result [5] := '.';
  if Attr and faArchive   = 0 then Result [6] := '.';
end;

function PosText;
begin
  Result := Pos (LowerCase (Substr), LowerCase (S));
end;

function SetPriority (Priority: integer): TThreadPriority; // Priority is 0..3
const
  PriorityValue: array [0..3] of TThreadPriority = (tpTimeCritical, tpHigher, tpNormal, tpIdle);
begin
  if Priority in [0..3] then
    Result := PriorityValue [Max (0, Min (Priority, 3))]
  else
    Result := tpNormal;
end;


// --------------------------------------------------- //
//                                                     //
// CheckOut and Temp Directory                         //
//                                                     //
// --------------------------------------------------- //

  procedure DeletePathScan (const Path: String);
  var
    T: TSearchRec;
  begin
    if FindFirst (IncludeDelimiter (Path) + '*.*', faAnyFile - faDirectory, T) = 0 then
      repeat
        if (not (T.Name = '.')) and (not (T.Name = '..')) then
          DeleteFile (IncludeDelimiter (Path) + T.Name);
      until not (FindNext (T) = 0);
    FindClose (T);

    if FindFirst (IncludeDelimiter (Path) + '*.*', faDirectory, T) = 0 then
      repeat
        if (not (T.Name = '.')) and (not (T.Name = '..')) then
          DeletePathScan (IncludeDelimiter (Path) + T.Name);
      until not (FindNext (T) = 0);
    FindClose (T);

    RemoveDir (Path);
  end;
  
function ReturnCheckOutDir;
begin
  Result := ExtractFilePath (ParamStr (0)) + CHECKOUTDIR;
end;

function ReturnTempDir;
begin
  Result := ExtractFilePath (ParamStr (0)) + TEMPDIR;
end;

procedure DeleteCheckOutDir;
begin
  if not SetCurrentDir (ReturnCheckOutDir) then Exit;
  if not SetCurrentDir (ExtractFilePath (ReturnCheckOutDir)) then Exit;
  DeletePathScan (ReturnCheckOutDir);
  RemoveDir (ReturnCheckOutDir);
end;

procedure DeleteTempDir;
begin
  if not SetCurrentDir (ReturnTempDir) then Exit;
  if not SetCurrentDir (ExtractFilePath (ReturnTempDir)) then Exit;
  DeletePathScan (ReturnTempDir);
  RemoveDir (ReturnTempDir);
end;

end.
